@@ -1,7 +1,7 @@
 #############################################################################
 #
 # XLConnect
-# Copyright (C) 2010-2025 Mirai Solutions GmbH
+# Copyright (C) 2010-2026 Mirai Solutions GmbH
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -58,26 +58,26 @@
   sharedPaths <- tryCatch({
     c(
       xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/poi/poi-ooxml-full/5.4.1/poi-ooxml-full-5.4.1.jar"), "poi-ooxml-full.jar", 
-      "5.4.1",  libname, pkgname),
+      paste0(apachePrefix, "/poi/poi-ooxml-full/5.5.1/poi-ooxml-full-5.5.1.jar"), "poi-ooxml-full.jar",
+      "5.5.1",  libname, pkgname),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/poi/poi-ooxml/5.4.1/poi-ooxml-5.4.1.jar"), "poi-ooxml.jar", 
-      "5.4.1",  libname, pkgname, debianpkg = "libapache-poi-java", rpmpkg="apache-poi"),
+      paste0(apachePrefix, "/poi/poi-ooxml/5.5.1/poi-ooxml-5.5.1.jar"), "poi-ooxml.jar",
+      "5.5.1",  libname, pkgname, debianpkg = "libapache-poi-java", rpmpkg="apache-poi"),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/poi/poi/5.4.1/poi-5.4.1.jar"), "poi.jar", 
-      "5.4.1",  libname, pkgname, debianpkg = "libapache-poi-java", rpmpkg="apache-poi"),
+      paste0(apachePrefix, "/poi/poi/5.5.1/poi-5.5.1.jar"), "poi.jar",
+      "5.5.1",  libname, pkgname, debianpkg = "libapache-poi-java", rpmpkg="apache-poi"),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/commons/commons-compress/1.27.1/commons-compress-1.27.1.jar"), "commons-compress.jar",
-      "1\\.(2[5-9]|[2-9][0-9]).*",  libname, pkgname, debianpkg = "libcommons-compress-java", rpmpkg="apache-commons-compress"),
+      paste0(apachePrefix, "/commons/commons-compress/1.28.0/commons-compress-1.28.0.jar"), "commons-compress.jar",
+      "1\\.(2[8-9]|[3-9][0-9]).*",  libname, pkgname, debianpkg = "libcommons-compress-java", rpmpkg="apache-commons-compress"),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/commons/commons-lang3/3.16.0/commons-lang3-3.16.0.jar"), "commons-lang3-3.16.0.jar",
-      "3\\.(1[4-9]|[2-9][0-9])\\.*",  libname, pkgname, debianpkg="libcommons-lang3-java", rpmpkg="apache-commons-lang3"),
+      paste0(apachePrefix, "/commons/commons-lang3/3.18.0/commons-lang3-3.18.0.jar"), "commons-lang3-3.18.0.jar",
+      "3\\.(1[8-9]|[2-9][0-9])\\.*",  libname, pkgname, debianpkg="libcommons-lang3-java", rpmpkg="apache-commons-lang3"),
     xlcEnsureDependenciesFor(
       paste0(apachePrefix, "/xmlbeans/xmlbeans/5.3.0/xmlbeans-5.3.0.jar"), "xmlbeans.jar",
       "5\\..*",  libname, pkgname, debianpkg="libxmlbeans-java"),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/commons/commons-collections4/4.4/commons-collections4-4.4.jar"), "commons-collections4.jar",
-      "4-4\\.([2-9]|1[0-9]).*",  libname, pkgname, debianpkg="libcommons-collections4-java", rpmpkg="apache-commons-collections4"),
+      paste0(apachePrefix, "/commons/commons-collections4/4.5.0/commons-collections4-4.5.0.jar"), "commons-collections4.jar",
+      "4\\.5.*",  libname, pkgname, debianpkg="libcommons-collections4-java", rpmpkg="apache-commons-collections4"),
     xlcEnsureDependenciesFor(
       paste0(apachePrefix, "/commons/commons-math3/3.6.1/commons-math3-3.6.1.jar"), "commons-math3.jar",
       "3\\.([6-9]|1[0-9]).*",  libname, pkgname, debianpkg="libcommons-math3-java"),
@@ -85,11 +85,11 @@
       paste0(apachePrefix, "/logging/log4j/log4j-api/2.24.3/log4j-api-2.24.3.jar"), "log4j-api.jar",
       "2\\.24\\..*",  libname, pkgname),
     xlcEnsureDependenciesFor(
-      paste0(repo, "/commons-codec/commons-codec/1.18.0/commons-codec-1.18.0.jar"), "commons-codec-1.18.0.jar",
-      "1\\.(1[1-9]|[2-9][0-9]).*",  libname, pkgname, debianpkg="libcommons-codec-java", rpmpkg="apache-commons-codec"),
+      paste0(repo, "/commons-codec/commons-codec/1.20.0/commons-codec-1.20.0.jar"), "commons-codec-1.20.0.jar",
+      "1\\.(20|[2-9][0-9]).*",  libname, pkgname, debianpkg="libcommons-codec-java", rpmpkg="apache-commons-codec"),
     xlcEnsureDependenciesFor(
-      paste0(repo, "/commons-io/commons-io/2.18.0/commons-io-2.18.0.jar"), "commons-io-2.18.0.jar",
-      "2\\.(1[5-9]|[2-9][0-9]).*",  libname, pkgname, debianpkg="libcommons-io-java", rpmpkg="apache-commons-io"),
+      paste0(repo, "/commons-io/commons-io/2.21.0/commons-io-2.21.0.jar"), "commons-io-2.21.0.jar",
+      "2\\.(21|[3-9][0-9]).*",  libname, pkgname, debianpkg="libcommons-io-java", rpmpkg="apache-commons-io"),
     xlcEnsureDependenciesFor(
       paste0(repo, "/com/zaxxer/SparseBitSet/1.3/SparseBitSet-1.3.jar"), "SparseBitSet.jar",
       "1\\.([2-9]|[1-9][0-9]).*",  libname, pkgname)
@@ -99,7 +99,16 @@
           e
         }
   )
-  .jpackage(name = pkgname, jars = "*", morePaths = sharedPaths, own.loader=TRUE)  
+  classPath = tryCatch(.jclassPath(), error = function(e) character())
+  poiJars <- grep("(?:^|[/\\\\])poi-[^/\\\\]*\\.jar$", classPath, ignore.case = FALSE, value = TRUE, perl = TRUE)
+  if (length(poiJars) > 0) {
+    warning(
+    "'poi' jars were loaded by a different package in the main class loader:\n",
+    paste(poiJars, collapse = "\n"),
+    "\nTo ensure XLConnect functions correctly, start R without loading other Excel-related packages such as 'xlsx'."
+    )
+  }
+  .jpackage(name = pkgname, jars = "*", morePaths = sharedPaths, own.loader=TRUE)
   # Perform general XLConnect settings - pass package description
   XLConnectSettings(packageDescription(pkgname))
 }
